/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CredentialStoreStaticConfig extends cdktf.TerraformMetaArguments {
    /**
    * The static credential store description.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/boundary/1.1.15/docs/resources/credential_store_static#description CredentialStoreStatic#description}
    */
    readonly description?: string;
    /**
    * The static credential store name. Defaults to the resource name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/boundary/1.1.15/docs/resources/credential_store_static#name CredentialStoreStatic#name}
    */
    readonly name?: string;
    /**
    * The scope for this credential store.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/boundary/1.1.15/docs/resources/credential_store_static#scope_id CredentialStoreStatic#scope_id}
    */
    readonly scopeId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/boundary/1.1.15/docs/resources/credential_store_static boundary_credential_store_static}
*/
export declare class CredentialStoreStatic extends cdktf.TerraformResource {
    static readonly tfResourceType = "boundary_credential_store_static";
    /**
    * Generates CDKTF code for importing a CredentialStoreStatic resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the CredentialStoreStatic to import
    * @param importFromId The id of the existing CredentialStoreStatic that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/boundary/1.1.15/docs/resources/credential_store_static#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the CredentialStoreStatic to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/boundary/1.1.15/docs/resources/credential_store_static boundary_credential_store_static} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CredentialStoreStaticConfig
    */
    constructor(scope: Construct, id: string, config: CredentialStoreStaticConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _scopeId?;
    get scopeId(): string;
    set scopeId(value: string);
    get scopeIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
